"""
# Ventx AWS CDK Library

Check out the Documentation on [github](https://github.com/ventx/aws-cdk-library).
"""
import abc
import builtins
import datetime
import enum
import typing

import jsii
import jsii.compat
import publication

from ._jsii import *

import aws_cdk.aws_ec2
import aws_cdk.aws_s3
import aws_cdk.core


class BastionHost(aws_cdk.core.Construct, metaclass=jsii.JSIIMeta, jsii_type="@ventx/aws-cdk-library.BastionHost"):
    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, image: aws_cdk.aws_ec2.IMachineImage, key_name: str, peers: typing.List[aws_cdk.aws_ec2.IPeer], vpc: aws_cdk.aws_ec2.IVpc, instance_type: typing.Optional[aws_cdk.aws_ec2.InstanceType]=None, subnets: typing.Optional[aws_cdk.aws_ec2.SubnetSelection]=None) -> None:
        """
        :param scope: -
        :param id: -
        :param image: -
        :param key_name: -
        :param peers: -
        :param vpc: -
        :param instance_type: -
        :param subnets: -
        """
        props = BastionHostProps(image=image, key_name=key_name, peers=peers, vpc=vpc, instance_type=instance_type, subnets=subnets)

        jsii.create(BastionHost, self, [scope, id, props])

    @builtins.property
    @jsii.member(jsii_name="internalSshSecurityGroup")
    def internal_ssh_security_group(self) -> aws_cdk.aws_ec2.ISecurityGroup:
        return jsii.get(self, "internalSshSecurityGroup")

    @builtins.property
    @jsii.member(jsii_name="publicIp")
    def public_ip(self) -> str:
        return jsii.get(self, "publicIp")


@jsii.data_type(jsii_type="@ventx/aws-cdk-library.BastionHostProps", jsii_struct_bases=[], name_mapping={'image': 'image', 'key_name': 'keyName', 'peers': 'peers', 'vpc': 'vpc', 'instance_type': 'instanceType', 'subnets': 'subnets'})
class BastionHostProps():
    def __init__(self, *, image: aws_cdk.aws_ec2.IMachineImage, key_name: str, peers: typing.List[aws_cdk.aws_ec2.IPeer], vpc: aws_cdk.aws_ec2.IVpc, instance_type: typing.Optional[aws_cdk.aws_ec2.InstanceType]=None, subnets: typing.Optional[aws_cdk.aws_ec2.SubnetSelection]=None) -> None:
        """
        :param image: -
        :param key_name: -
        :param peers: -
        :param vpc: -
        :param instance_type: -
        :param subnets: -
        """
        if isinstance(subnets, dict): subnets = aws_cdk.aws_ec2.SubnetSelection(**subnets)
        self._values = {
            'image': image,
            'key_name': key_name,
            'peers': peers,
            'vpc': vpc,
        }
        if instance_type is not None: self._values["instance_type"] = instance_type
        if subnets is not None: self._values["subnets"] = subnets

    @builtins.property
    def image(self) -> aws_cdk.aws_ec2.IMachineImage:
        return self._values.get('image')

    @builtins.property
    def key_name(self) -> str:
        return self._values.get('key_name')

    @builtins.property
    def peers(self) -> typing.List[aws_cdk.aws_ec2.IPeer]:
        return self._values.get('peers')

    @builtins.property
    def vpc(self) -> aws_cdk.aws_ec2.IVpc:
        return self._values.get('vpc')

    @builtins.property
    def instance_type(self) -> typing.Optional[aws_cdk.aws_ec2.InstanceType]:
        return self._values.get('instance_type')

    @builtins.property
    def subnets(self) -> typing.Optional[aws_cdk.aws_ec2.SubnetSelection]:
        return self._values.get('subnets')

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return 'BastionHostProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())


class BucketCleanupFunction(aws_cdk.core.Construct, metaclass=jsii.JSIIMeta, jsii_type="@ventx/aws-cdk-library.BucketCleanupFunction"):
    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, bucket: aws_cdk.aws_s3.IBucket) -> None:
        """
        :param scope: -
        :param id: -
        :param bucket: -
        """
        props = BucketCleanupFunctionProps(bucket=bucket)

        jsii.create(BucketCleanupFunction, self, [scope, id, props])


@jsii.data_type(jsii_type="@ventx/aws-cdk-library.BucketCleanupFunctionProps", jsii_struct_bases=[], name_mapping={'bucket': 'bucket'})
class BucketCleanupFunctionProps():
    def __init__(self, *, bucket: aws_cdk.aws_s3.IBucket) -> None:
        """
        :param bucket: -
        """
        self._values = {
            'bucket': bucket,
        }

    @builtins.property
    def bucket(self) -> aws_cdk.aws_s3.IBucket:
        return self._values.get('bucket')

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return 'BucketCleanupFunctionProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())


class SamlProvider(aws_cdk.core.Construct, metaclass=jsii.JSIIMeta, jsii_type="@ventx/aws-cdk-library.SamlProvider"):
    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, metadata_document: str) -> None:
        """
        :param scope: -
        :param id: -
        :param metadata_document: -
        """
        props = SamlProviderProps(metadata_document=metadata_document)

        jsii.create(SamlProvider, self, [scope, id, props])


@jsii.data_type(jsii_type="@ventx/aws-cdk-library.SamlProviderProps", jsii_struct_bases=[], name_mapping={'metadata_document': 'metadataDocument'})
class SamlProviderProps():
    def __init__(self, *, metadata_document: str) -> None:
        """
        :param metadata_document: -
        """
        self._values = {
            'metadata_document': metadata_document,
        }

    @builtins.property
    def metadata_document(self) -> str:
        return self._values.get('metadata_document')

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return 'SamlProviderProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())


__all__ = [
    "BastionHost",
    "BastionHostProps",
    "BucketCleanupFunction",
    "BucketCleanupFunctionProps",
    "SamlProvider",
    "SamlProviderProps",
]

publication.publish()
